@@ -5,7 +5,7 @@ refactored 6-mar-2020
 """
 
 from base64 import b64encode
-from datetime import datetime, timedelta
+from datetime import timedelta
 from flask import g, request
 from flask_babel import _
 import hashlib
@@ -16,7 +16,7 @@ from sqlalchemy.orm.exc import NoResultFound
 import yaml
 
 from .service_config import ServiceConfig
-from .utils import gen_id
+from .utils import gen_id, utcnow
 
 LEVELS = {}
 POLICIES = {}
@@ -147,7 +147,7 @@ class AccessControl(object):
         if access in rbac:
             return True
         else:
-            duration = (datetime.utcnow().timestamp() -
+            duration = (utcnow().timestamp() -
                         g.request_start_time.timestamp())
             logging.info(dict(
                 action='with_permission', message=_('access denied'),
@@ -288,7 +288,6 @@ class AccessControl(object):
         bits) are an access key ID prefix; last 32 characters (192
         bits) are the secret key.
 
-
         Returns: tuple
           key ID (str) - public portion of key
           secret (str) - secret portion
@@ -314,9 +313,9 @@ class AccessControl(object):
                 prefix=key_id, hashvalue=self.apikey_hash(secret),
                 status='active').one()
             if not record.last_used or (
-                    record.last_used + timedelta(hours=6) < datetime.utcnow()
-                    and record.expires < datetime.utcnow()):
-                record.last_used = datetime.utcnow()
+                    record.last_used + timedelta(hours=6) < utcnow()
+                    and record.expires < utcnow()):
+                record.last_used = utcnow()
                 g.db.commit()
         except NoResultFound:
             logging.info(dict(action='api_key', key_id=key_id,
@@ -325,7 +324,7 @@ class AccessControl(object):
         except Exception as ex:
             logging.error(dict(action='api_key', message=str(ex)))
             return None, None
-        if record.expires and record.expires < datetime.now():
+        if record.expires and record.expires < utcnow():
             logging.info(dict(action='api_key', key_id=key_id,
                               uid=record.uid, message='expired'))
             return None, None
