@@ -27,7 +27,7 @@ class AccountSettings(object):
 
     Args:
       account_id (str): ID in database of a user's account
-      db_session (obj): a session connected to datbase
+      db_session (obj): a session connected to database
       uid (str): User ID
     """
     def __init__(self, account_id, db_session=None, uid=None):
@@ -84,7 +84,8 @@ class AccountSettings(object):
                         tz=record.tz.name)))
             try:
                 senders = db_session.query(models.List).filter_by(
-                    name=config.APPROVED_SENDERS, uid=account.uid).one()
+                    name=config.APPROVED_SENDERS,
+                    uid=record.administrator_id).one()
                 SETTINGS[account_id]['settings']['approved_senders'] = (
                     [member.identity for member in senders.members])
             except NoResultFound:
@@ -95,6 +96,10 @@ class AccountSettings(object):
         self.db_session = db_session
         self.default_locale = ServiceConfig().config.BABEL_DEFAULT_LOCALE
 
+    def uncache(self):
+        """Clear the cached settings for account_id"""
+        SETTINGS.pop(self.account_id, None)
+
     @property
     def locale(self):
         """Returns the language for the uid if specified in the
